/*
 * PokeFrog - A 'Pokemonized' verison of Frogger, the well-known Konami game.
 *
 * copyright (c) 2012 Fabien LOISON <http://www.flogisoft.com/>
 * 
 * this program is free software. it comes without any warranty, to
 * the extent permitted by applicable law. you can redistribute it
 * and/or modify it under the terms of the do what the fuck you want
 * to public license, version 2, as published by sam hocevar. see
 * http://sam.zoy.org/wtfpl/copying for more details. 
 */


/**
 * @module PokeFrog
 */


/**
 * Manages a lily (frog's destination).
 *
 * @class Lily
 * @constructor
 *
 * @param {wjs.Tileset} tileset The tileset that contains the `pokeball` tile.
 * @param {Number} x The x position of the lily.
 * @param {Number} y The y position of the lily.
 * @param {Number} width The width of the lily.
 * @param {Number} height The height of the lily.
 */
function Lily(tileset, x, y, width, height)
{
	this._tileset = tileset;
	this._x = x;
	this._y = y;
	this._width = width;
	this._height = height;

	/**
	 * `true` if the player already took the lily, `false` else;
	 * 
	 * @property taken
	 * @type Boolean
	 */
	this.taken = false;
}

/**
 * Calculate the position of the lily's hitbox on the canvas.
 *
 * @method getHitbox
 *
 * @return {Array} The hitbox: `[x1, y1, x2, y2]`.
 */
Lily.prototype.getHitbox = function()
{
	return [
		this._x + 20,  // x1
		this._y + 15,  // y1
		this._x + this._width - 20,   // x2
		this._y + this._height - 15]  // y2
}

/**
 * Draw a pokeball on the lily if it is taken.
 *
 * @method draw
 */
Lily.prototype.draw = function()
{
	if (this.taken)
	{
		this._tileset.blit(
				'pokeball',
				this._x + Math.floor((this._width - 32) / 2),
				this._y + Math.floor((this._height - 32) / 2)
				);
	}

	// Debug: display the hitbox
	if (DEBUG)
	{
		var ctx = wjs.canvas.getContext('2d');
		var hitbox = this.getHitbox();
		ctx.lineWidth = 2;
		ctx.strokeStyle = '#f00';
		ctx.strokeRect(
				hitbox[0],  // x
				hitbox[1],  // y
				hitbox[2]-hitbox[0],  // width
				hitbox[3]-hitbox[1]); // height
	}
}
